@@ -51,6 +51,10 @@ print "ok 1\n";
 		}
 	}
 
+	$_ = 'ALL RIGHT';
+
+	println;
+
 ######################### End of black magic.
 
 # Insert your test code below (better if it prints "ok 13"
